@@ -36,21 +36,35 @@ License along with liblouis. If not, see <http://www.gnu.org/licenses/>.
 extern "C" {
 #endif /* __cplusplus */
 
-typedef unsigned short int widechar;
+typedef unsigned int widechar;
 typedef unsigned short formtype;
 
-#ifdef _WIN32
+#ifdef _MSC_VER
+  #ifdef _EXPORTING
+    #define LIBLOUIS_API __declspec(dllexport)
+  #else
+    #define LIBLOUIS_API __declspec(dllimport)
+  #endif
+#else
+  #define LIBLOUIS_API
+#endif
+
+#ifdef __EMSCRIPTEN__
+#include "emscripten.h"
+#define EXPORT_CALL EMSCRIPTEN_KEEPALIVE
+#elif defined(_WIN32)
 #define EXPORT_CALL __stdcall
-char *EXPORT_CALL lou_getProgramPath();
+LIBLOUIS_API
+char *EXPORT_CALL lou_getProgramPath(void);
 #else
 #define EXPORT_CALL
 #endif
 
 typedef enum {
   plain_text = 0x0000,
-  italic = 0x0001,     // emph_1
-  underline = 0x0002,  // emph_2
-  bold = 0x0004,       // emph_3
+  emph_1 = 0x0001,
+  emph_2 = 0x0002,
+  emph_3 = 0x0004,
   emph_4 = 0x0008,
   emph_5 = 0x0010,
   emph_6 = 0x0020,
@@ -61,13 +75,22 @@ typedef enum {
   computer_braille = 0x0400,
   no_translate = 0x0800,
   no_contract = 0x1000,
-  // unused  0x2000,
-  // used by syllable  0x4000,
-  // used by syllable  0x8000
+  // SYLLABLE_MARKER_1  0x2000,
+  // SYLLABLE_MARKER_1  0x4000
+  // CAPSEMPH  0x4000
 } typeforms;
-#define comp_emph_1 italic
-#define comp_emph_2 underline
-#define comp_emph_3 bold
+
+#define italic    emph_1
+#define underline emph_2
+#define bold      emph_3
+
+#define comp_emph_1 emph_1
+#define comp_emph_2 emph_2
+#define comp_emph_3 emph_3
+
+#define EMPH_NAME_BOLD "bold"
+#define EMPH_NAME_ITALIC "italic"
+#define EMPH_NAME_UNDERLINE "underline"
 
 typedef enum {
   noContractions = 1,
@@ -77,27 +100,34 @@ typedef enum {
   pass1Only = 16,
   compbrlLeftCursor = 32,
   otherTrans = 64,
-  ucBrl = 128
+  ucBrl = 128,
+  noUndefinedDots = 256,
+  partialTrans = 512
 } translationModes;
 
-char *EXPORT_CALL lou_version();
+LIBLOUIS_API
+char *EXPORT_CALL lou_version(void);
 
 /**
  * Return the size of widechar
  */
-int EXPORT_CALL lou_charSize();
+LIBLOUIS_API
+int EXPORT_CALL lou_charSize(void);
 
+LIBLOUIS_API
 int EXPORT_CALL lou_translateString(const char *tableList,
                                     const widechar *inbuf, int *inlen,
                                     widechar *outbuf, int *outlen,
                                     formtype *typeform, char *spacing,
                                     int mode);
 
+LIBLOUIS_API
 int EXPORT_CALL lou_translate(const char *tableList, const widechar *inbuf,
                               int *inlen, widechar *outbuf, int *outlen,
                               formtype *typeform, char *spacing, int *outputPos,
                               int *inputPos, int *cursorPos, int mode);
 
+LIBLOUIS_API
 int EXPORT_CALL lou_translatePrehyphenated(const char *tableList,
                                            const widechar *inbuf, int *inlen,
                                            widechar *outbuf, int *outlen,
@@ -106,18 +136,23 @@ int EXPORT_CALL lou_translatePrehyphenated(const char *tableList,
                                            int *cursorPos, char *inputHyphens,
                                            char *outputHyphens, int mode);
 
+LIBLOUIS_API
 int EXPORT_CALL lou_hyphenate(const char *tableList, const widechar *inbuf,
                               int inlen, char *hyphens, int mode);
+LIBLOUIS_API
 int EXPORT_CALL lou_dotsToChar(const char *tableList, widechar *inbuf,
                                widechar *outbuf, int length, int mode);
+LIBLOUIS_API
 int EXPORT_CALL lou_charToDots(const char *tableList, const widechar *inbuf,
                                widechar *outbuf, int length, int mode);
+LIBLOUIS_API
 int EXPORT_CALL lou_backTranslateString(const char *tableList,
                                         const widechar *inbuf, int *inlen,
                                         widechar *outbuf, int *outlen,
                                         formtype *typeform, char *spacing,
                                         int mode);
 
+LIBLOUIS_API
 int EXPORT_CALL lou_backTranslate(const char *tableList, const widechar *inbuf,
                                   int *inlen, widechar *outbuf, int *outlen,
                                   formtype *typeform, char *spacing,
@@ -129,13 +164,18 @@ int EXPORT_CALL lou_backTranslate(const char *tableList, const widechar *inbuf,
  * @deprecated As of 2.6.0, applications using liblouis should
  * implement their own logging system.
  */
+LIBLOUIS_API
 void EXPORT_CALL lou_logPrint(const char *format, ...);
 
 /**
  * Specify the name of the file to be used by lou_logPrint.
  *
  * If it is not used, this file is stderr
+ *
+ * @deprecated As of 2.6.0, applications using liblouis should
+ * implement their own logging system.
  */
+LIBLOUIS_API
 void EXPORT_CALL lou_logFile(const char *filename);
 
 /**
@@ -144,12 +184,17 @@ void EXPORT_CALL lou_logFile(const char *filename);
  * and return it as an integer. EOF at end of file. Mode = 1 on first
  * call, any other value thereafter
  */
+LIBLOUIS_API
 int EXPORT_CALL lou_readCharFromFile(const char *fileName, int *mode);
 
 /**
  * Close the log file so it can be read by other functions.
+ *
+ * @deprecated As of 2.6.0, applications using liblouis should
+ * implement their own logging system.
  */
-void EXPORT_CALL lou_logEnd();
+LIBLOUIS_API
+void EXPORT_CALL lou_logEnd(void);
 
 /**
  * Load and compile a translation table
@@ -160,6 +205,7 @@ void EXPORT_CALL lou_logEnd();
  * lou_backTranslateString() and also by functions in liblouisutdml
  * and by the tools.
  */
+LIBLOUIS_API
 void *EXPORT_CALL lou_getTable(const char *tableList);
 
 /**
@@ -168,12 +214,14 @@ void *EXPORT_CALL lou_getTable(const char *tableList);
  * If no errors are found it load the table into memory and returns a
  * non-zero value. Else the return value is 0.
  */
+LIBLOUIS_API
 int EXPORT_CALL lou_checkTable(const char *tableList);
 
 /**
  * Register a new table resolver. Overrides the default resolver. */
+LIBLOUIS_API
 void EXPORT_CALL lou_registerTableResolver(
-    char **(*resolver)(const char *table, const char *base));
+    char **(EXPORT_CALL *resolver)(const char *table, const char *base));
 
 /**
  * Compile a table entry on the fly at run-time
@@ -188,6 +236,7 @@ void EXPORT_CALL lou_registerTableResolver(
  *
  * @return 1 on success and 0 on failure.
  */
+LIBLOUIS_API
 int EXPORT_CALL lou_compileString(const char *tableList, const char *inString);
 
 /**
@@ -196,17 +245,29 @@ int EXPORT_CALL lou_compileString(const char *tableList, const char *inString);
  * If the table defines the specified emphasis class the corresponding
  * typeform is returned. Else the return value is 0.
  */
+LIBLOUIS_API
 formtype EXPORT_CALL lou_getTypeformForEmphClass(const char *tableList, const char *emphClass);
 
+/**
+ * Return the emphasis class names declared in tableList as a
+ * NULL-terminated array of strings. The array is acquired with malloc()
+ * and should be released with free(). The strings must not be released,
+ * and are no longer valid after lou_free() has been called.
+ */
+LIBLOUIS_API
+char const **EXPORT_CALL lou_getEmphClasses(const char *tableList);
+
 /**
  * Set the path used for searching for tables and liblouisutdml files.
  *
  * Overrides the installation path. */
+LIBLOUIS_API
 char *EXPORT_CALL lou_setDataPath(const char *path);
 
 /**
  * Get the path set in the previous function. */
-char *EXPORT_CALL lou_getDataPath();
+LIBLOUIS_API
+char *EXPORT_CALL lou_getDataPath(void);
 
 typedef enum {
   LOG_ALL = 0,
@@ -224,11 +285,13 @@ typedef void (*logcallback)(logLevels level, const char *message);
  * Register logging callbacks
  * Set to NULL for default callback.
  */
+LIBLOUIS_API
 void EXPORT_CALL lou_registerLogCallback(logcallback callback);
 
 /**
  * Set the level for logging callback to be called at
  */
+LIBLOUIS_API
 void EXPORT_CALL lou_setLogLevel(logLevels level);
 
 /* =========================  BETA API ========================= */
@@ -242,6 +305,7 @@ void EXPORT_CALL lou_setLogLevel(logLevels level);
  * message is given when a table contains invalid or duplicate
  * metadata fields.
  */
+LIBLOUIS_API
 void EXPORT_CALL lou_indexTables(const char **tables);
 
 /**
@@ -250,6 +314,7 @@ void EXPORT_CALL lou_indexTables(const char **tables);
  * Returns a string with the table name. Returns NULL when no match
  * can be found. An error message is given when the query is invalid.
  */
+LIBLOUIS_API
 char *EXPORT_CALL lou_findTable(const char *query);
 
 /* ====================== END OF BETA API ====================== */
@@ -260,7 +325,8 @@ char *EXPORT_CALL lou_findTable(const char *query);
  * This function should be called at the end of the application to
  * free all memory allocated by liblouis.
  */
-void EXPORT_CALL lou_free();
+LIBLOUIS_API
+void EXPORT_CALL lou_free(void);
 
 #ifdef __cplusplus
 }
