@@ -70,12 +70,14 @@ try:
 except NameError:
     # Unix/Cygwin
     _loader = cdll
-liblouis = _loader["liblouis.so.12"]
+liblouis = _loader["liblouis.so.14"]
 
 atexit.register(liblouis.lou_free)
 
 liblouis.lou_version.restype = c_char_p
 
+liblouis.lou_charSize.restype = c_int
+
 liblouis.lou_translateString.argtypes = (
     c_char_p, c_wchar_p, POINTER(c_int), c_wchar_p, 
          POINTER(c_int), POINTER(c_ushort), POINTER(c_char), c_int)
@@ -111,6 +113,13 @@ def version():
     """
     return liblouis.lou_version().decode("ASCII")
 
+def charSize():
+    """Obtain charSize information for liblouis.
+    @return: The size of the widechar with which liblouis was compiled.
+    @rtype: int
+    """
+    return liblouis.lou_charSize()
+
 def translate(tableList, inbuf, typeform=None, cursorPos=0, mode=0):
     """Translate a string of characters, providing position information.
     @param tableList: A list of translation tables.
@@ -344,8 +353,15 @@ pass1Only = 16
 compbrlLeftCursor = 32
 otherTrans = 64
 ucBrl = 128
+noUndefinedDots = 256
+partialTrans = 512
 #}
 
+if charSize() == 2 and sys.maxunicode != 65535:
+    raise Exception("mismatch in Unicode width: liblouis is 2 and python isn't")
+elif charSize() == 4 and sys.maxunicode != 1114111:
+    raise Exception("mismatch in Unicode width: liblouis is 4 and python isn't")
+
 if __name__ == '__main__':
     # Just some common tests.
     print(version())
